OC.L10N.register(
    "core",
    {
    "Please select a file." : "Lūdzu izvēlies datni.",
    "File is too big" : "Datne ir par lielu",
    "The selected file is not an image." : "Atlasītā datne nav attēls.",
    "The selected file cannot be read." : "Atlasīto datni nevar nolasīt.",
    "Invalid file provided" : "Norādīta nederīga datne",
    "No image or file provided" : "Nav norādīts attēls vai datne",
    "Unknown filetype" : "Nezināms datnes tips",
    "Invalid image" : "Nederīgs attēls",
    "An error occurred. Please contact your admin." : "Notika kļūda. Lūdzu sazinies ar savu administratoru.",
    "No temporary profile picture available, try again" : "Profila pagaidu attēls nav pieejams, mēģini vēlreiz",
    "No crop data provided" : "Nav norādīti apgriešanas dati",
    "No valid crop data provided" : "Nav norādīti derīgi apgriešanas dati",
    "Crop is not square" : "Griezums nav kvadrāts",
    "State token does not match" : "Neatbilstošs stāvokļa talons",
    "Password reset is disabled" : "Paroles atiestatīšana nav iespējota",
    "Couldn't reset password because the token is invalid" : "Nevarēja nomainīt paroli, jo pazīšanās zīme ir nederīga",
    "Couldn't reset password because the token is expired" : "Nevarēja nomainīt paroli, jo pazīšanās zīmei beidzies derīguma termiņš",
    "%s password reset" : "%s paroles maiņa",
    "Password reset" : "Parole atiestatīta",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nospiediet sekojošo pogu, lai atiestatītu paroli. Ja jūs nepieprasijāt paroles atiestatīšanu, ignorējiet šo e-pastu.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nospiediet sekojošo saiti, lai atiestatītu paroli. Ja jūs nepieprasijāt paroles atiestatīšanu, ignorējiet šo e-pastu.",
    "Reset your password" : "Atiestatīt paroli",
    "Nextcloud Server" : "Nextcloud Serveris",
    "Preparing update" : "Sagatavo atjauninājumu",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Lūdzu izmanto komandrindas atjaunināšanu, jo automātiskā atjaunināšana ir atspējota konfigurācijas datnē config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Pārbauda tabulu %s",
    "Turned on maintenance mode" : "Ieslēgts uzturēšanas režīms",
    "Turned off maintenance mode" : "Izslēgts uzturēšanas režīms",
    "Maintenance mode is kept active" : "Uzturēšanas režīms ir paturēts aktīvs",
    "Updating database schema" : "Atjaunina datu bāzes shēmu",
    "Updated database" : "Atjaunināta datu bāze",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Pārbauda vai datu bāzes shēma var būt atjaunināma (tas var prasīt laiku atkarībā no datu bāzes izmēriem)",
    "Checked database schema update" : "Pārbaudīts datu bāzes shēmas atjauninājums",
    "Checking updates of apps" : "Pārbauda lietotņu atjauninājumus",
    "Checking for update of app \"%s\" in appstore" : "Meklē atjauninājumus lietotnei \"%s\"",
    "Update app \"%s\" from appstore" : "Atjaunināt lietotni \"%s\"",
    "Checked for update of app \"%s\" in appstore" : "Meklēti atjauninājumi lietotnei \"%s\"",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Nosaka, vai uz %s attiecināmā shēma var tikt atjaunināta (tas var prasīt daudz laiku atkarībā no datu bāzes izmēriem)",
    "Checked database schema update for apps" : "Pārbaudīts datu bāzes shēmas atjauninājums lietotnēm.",
    "Set log level to debug" : "Iestatīt žurnāla rakstīšanu uz atkļūdošanas režīmā",
    "Reset log level" : "Atiestatīt žurnāla rakstīšanas režīmu",
    "Starting code integrity check" : "Uzsākta koda integritātes pārbaude",
    "Finished code integrity check" : "Pabeigta  koda integritātes pārbaude",
    "%s (incompatible)" : "%s (nesaderīgs)",
    "Following apps have been disabled: %s" : "Sekojošas lietotnes tika atslēgtas: %s",
    "Already up to date" : "Jau ir jaunākā",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsu serveris nav pareizi uzstādīts lai atļautu datņu sinhronizēšanu jo WebDAV interfeiss šķiet salūzis.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Lūdzu pārbaudiet <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Instalācijas dokumentāciju </a> priekš PHP konfigurācijas piezīmēm un PHP konfigurācijai jūsu serverī, itsevisķi izmantojot php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu MIME tipus.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Transakciju datņu slēgšana ir izslēgta, tas var radīt problēmas ar race kondīcijām. Iespējo \"filelocking.enabled\" config.php datnē, lai novērstu šīs problēmas. Skatiet <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentāciju</a>priekš papildus informācijas.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebija iespējams paveikt cron darbu izmantojot CLI. Sekojošās tehniskās kļūdas ir uzradušās:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "Pēdējā fona darba palaišana aizņēma {relativeTime}. Kaut kas škiet nepareizi.",
    "Check the background job settings" : "Pārmainīt fona darbu iestatījumus",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Šim serverim nav interneta savienojuma. Tas nozīmē, ka daži līdzekļi, piemēram, ārējās atmiņas montēšana vai trešās puses lietotņu paziņojumi par atjauninājumiem nedarbosies. Iespējams nedarbosies attālināti piekļūt datnēm un nosūtīt paziņojumus uz e-pastu. Izveido interneta savienojumu ar serveri, lai visas funkcijas darbotos.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Tas ir īpaši ieteicams, ja, izmantojot darbvirsmas klientu, lai veiktu failu sinhronizāciju.",
    "Error occurred while checking server setup" : "Radās kļūda, pārbaudot servera ",
    "Non-existing tag #{tag}" : "Neeksistējošs tags #{tag}",
    "restricted" : "ierobežots",
    "invisible" : "Neredzams",
    "({scope})" : "({scope})",
    "Delete" : "Dzēst",
    "Rename" : "Pārsaukt",
    "Collaborative tags" : "Sadarbības birkas",
    "No tags found" : "Netika atrasta neviena birka",
    "unknown text" : "nezināms teksts",
    "Hello world!" : "Sveika, pasaule!",
    "sunny" : "saulains",
    "Hello {name}, the weather is {weather}" : "Sveiks {name}, laiks ir {weather}",
    "Hello {name}" : "Sveiks {name}",
    "new" : "jauns",
    "_download %n file_::_download %n files_" : ["lejupielādēt %n failus","lejupielādēt %n failus","lejupielādēt %n datnes"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Notiek atjaunināšana, šīs lapas atstāšana var pārtraukt procesu dažās vidēs.",
    "Update to {version}" : "Atjaunināts uz {version}",
    "An error occurred." : "Radās kļūda.",
    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjauninājums nebija veiksmīgs. Plašāku informāciju skatiet <a href=\"{url}\">mūsu foruma rakstā</a> par šo problēmu.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjauninājums nebija veiksmīgs. Lūdzu ziņojiet šo ķļūdu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienā</a>.",
    "Continue to Nextcloud" : "Turpināt ar Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundēm.","Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundes.","Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundēm."],
    "Searching other places" : "Meklēt citās vietās",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nav nekas atrasts citā mapēs {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} meklēšanas rezultāti citās mapēs","{count} meklēšanas rezultāti citās mapēs","{count} meklēšanas rezultāti citās mapēs"],
    "Server side authentication failed!" : "Servera autentifikācija neizdevās!",
    "Please contact your administrator." : "Lūdzu, sazinieties ar administratoru.",
    "An internal error occurred." : "Radās iekšēja kļūda.",
    "Please try again or contact your administrator." : "Lūdzu, mēģiniet vēlreiz vai sazinieties ar administratoru.",
    "Username or email" : "Lietotājvārds vai e-pasts",
    "Password" : "Parole",
    "Log in" : "Pieteikties",
    "Logging in …" : "Notiek pieteikšanās …",
    "Wrong username or password." : "Nepareizs lietotājvārds vai parole.",
    "User disabled" : "Lietotājs deaktivizēts",
    "Reset password" : "Mainīt paroli",
    "Couldn't send reset email. Please contact your administrator." : "Nevarēja nosūtīt maiņas e-pastu. Lūdzu sazinies ar savu administratoru.",
    "Password can not be changed. Please contact your administrator." : "Paroli, nevar nomainīt. Lūdzu kontaktēties ar savu administratoru.",
    "Back to login" : "Atpakaļ uz pieteikšanos",
    "New password" : "Jauna parole",
    "I know what I'm doing" : "Es zinu ko es daru",
    "Cancel" : "Atcelt",
    "Forgot password?" : "Aizmirsi paroli?",
    "Settings" : "Iestatījumi",
    "Could not load your contacts" : "Nevarēja ielādēt visas jūsu kontaktpersonas",
    "Search contacts …" : "Meklēt kontaktpersonu",
    "No contacts found" : "Nav atrasta ne viena kontaktpersona",
    "Show all contacts …" : "Rādīt visas kontaktpersonas",
    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
    "Looking for {term} …" : "Meklē {term} …",
    "No" : "Nē",
    "Yes" : "Jā",
    "No files in here" : "Šeit nav datņu",
    "New folder" : "Jauna mape",
    "No more subfolders in here" : "Šeit nav vairāk apakšmapju",
    "Name" : "Vārds",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "{newName} already exists" : "{newName} jau eksistē",
    "Choose" : "Izvēlieties",
    "Copy" : "Kopēt",
    "Move" : "Pārvietot",
    "Error loading file picker template: {error}" : "Kļūda ielādējot izvēlēto veidni: {error}",
    "OK" : "Labi",
    "Error loading message template: {error}" : "Kļūda ielādējot ziņojuma veidni: {error}",
    "read-only" : "tikai-skatīt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} datnes konflikts","{count} datnes konflikts","{count} datņu konflikti"],
    "One file conflict" : "Vienas datnes konflikts",
    "New Files" : "Jaunas datnes",
    "Already existing files" : "Jau esošas datnes",
    "Which files do you want to keep?" : "Kuras datnes vēlies paturēt?",
    "If you select both versions, the copied file will have a number added to its name." : "Ja izvēlēsietes paturēt abas versijas, kopētās datnes nosaukumam tiks pievienots skaitlis.",
    "Continue" : "Turpināt",
    "(all selected)" : "(visus iezīmētos)",
    "({count} selected)" : "({count} iezīmēti)",
    "Error loading file exists template" : "Kļūda ielādējot eksistējošas datnes veidni",
    "Pending" : "Gaida",
    "Copy to {folder}" : "Kopēt uz {folder}",
    "Move to {folder}" : "Pārvietot uz {folder}",
    "Saving..." : "Saglabā...",
    "Authentication required" : "Nepieciešama autentifikācija",
    "This action requires you to confirm your password" : "Lai veiktu šo darbību, jums jāievada sava parole.",
    "Confirm" : "Apstiprināt",
    "Failed to authenticate, try again" : "Neizdevās autentificēt, mēģiniet vēlreiz",
    "seconds ago" : "sekundes atpakaļ",
    "Connection to server lost" : "Zaudēts savienojums ar serveri",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm"],
    "Hide details" : "Slēpt detaļas",
    "View changelog" : "Skatīt izmaiņu sarakstu",
    "No action available" : "Nav pieejamu darbību",
    "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
    "Personal" : "Personīgi",
    "Users" : "Lietotāji",
    "Apps" : "Lietotnes",
    "Admin" : "Administratori",
    "Help" : "Palīdzība",
    "Access forbidden" : "Pieeja ir liegta",
    "File not found" : "Datne nav atrasta",
    "Error" : "Kļūda",
    "Internal Server Error" : "Iekšēja servera kļūda",
    "The server was unable to complete your request." : "Serveris nevarēja izpildīt tavu pieprasījumu.",
    "More details can be found in the server log." : "Sīkāka informācija atrodama servera žurnāla datnē.",
    "Technical details" : "Tehniskās detaļas",
    "Remote Address: %s" : "Attālinātā adrese: %s",
    "Request ID: %s" : "Pieprasījuma ID: %s",
    "Type: %s" : "Tips: %s",
    "Code: %s" : "Kods: %s",
    "Message: %s" : "Ziņojums: %s",
    "File: %s" : "Datne: %s",
    "Line: %s" : "Līnija: %s",
    "Trace" : "Izsekot",
    "Security warning" : "Drošības brīdinājums",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Visticamāk, jūsu datu direktorija un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
    "Create an <strong>admin account</strong>" : "Izveidot <strong>administratora kontu</strong>",
    "Username" : "Lietotājvārds",
    "Storage & database" : "Krātuve & datubāze",
    "Data folder" : "Datu mape",
    "Configure the database" : "Konfigurēt datubāzi",
    "Only %s is available." : "Tikai %s ir pieejams.",
    "Install and activate additional PHP modules to choose other database types." : "Instalējiet un aktivizējiet papildus PHP moduļus lai izvēlētos citus datubāžu tipus.",
    "For more details check out the documentation." : "Sīkākai informācijai skatiet dokumentāciju.",
    "Database user" : "Datubāzes lietotājs",
    "Database password" : "Datubāzes parole",
    "Database name" : "Datubāzes nosaukums",
    "Database tablespace" : "Datubāzes tabulas telpa",
    "Database host" : "Datubāzes serveris",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lūdzu, norādiet porta numuru kopā ar resursdatora nosaukumu (piemēram, localhost: 5432).",
    "Performance warning" : "Veiktspējas brīdinājums",
    "Finish setup" : "Pabeigt iestatīšanu",
    "Finishing …" : "Pabeidz ...",
    "Need help?" : "Vajadzīga palīdzība?",
    "See the documentation" : "Skatiet dokumentāciju",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Šai lietotnei nepieciešams JavaScript. Lūdzu {linkstart}ieslēdziet JavasScript{linkend} un pārlādējiet lapu.",
    "More apps" : "Vairāk lietotnes",
    "More" : "Vairāk",
    "Search" : "Meklēt",
    "Contacts" : "Kontakti",
    "Confirm your password" : "Apstipriniet paroli",
    "App token" : "Lietotnes pilnvara",
    "Grant access" : "Piešķirt pieeju",
    "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "Two-factor authentication" : "Divpakāpju autentifikācija",
    "Use backup code" : "Izmantojiet dublēšanas kodu",
    "Cancel login" : "Atcelt pieteikšanos",
    "Error while validating your second factor" : "Kļūda validējot jūsu otru faktoru.",
    "Access through untrusted domain" : "Piekļūt caur neuzticamu domēnu",
    "App update required" : "Lietotnei nepieciešama atjaunināšana",
    "These apps will be updated:" : "Šīs lietotnes tiks atjauninātas:",
    "These incompatible apps will be disabled:" : "Šīs nesaderīgās lietotnes tiks atspējotas:",
    "The theme %s has been disabled." : "Tēma %s ir atspējota.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Lūdzu pārliecinieties ka datubāze, config mape un data mape ir  dublētas pirms turpināšanas.",
    "Start update" : "Sākt atjaunināšanu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Lai izvairītos no noliedzes ar lielākām instalācijām, jūs varat palaist sekojošo komandu no jūsu instalācijas mapes:",
    "Detailed logs" : "Detalizēti žurnāli",
    "Update needed" : "Nepieciešama atjaunināšana",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Lūdzu, izmantojiet komandrindas atjauninātāju, jo jums ir vairāk nekā 50 lietotāji.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Es zinu ka ja es turpināšu atjauninājumu caur tīmekļa atjauninātāju ir risks ka pieprasījumam būs noliedze , kas var radīt  datu zudumu, bet man ir dublējumkopija un es zinu kā atjaunot instanci neveiksmes gadijumā.",
    "Upgrade via web on my own risk" : "Atjaunināt caur tīmekļa atjauninātāju uz mana paša risku.",
    "Maintenance mode" : "Uzturēšanas režīms",
    "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s serveris pašlaik darbojas uzturēšanas režīmā, tas var ilgt kādu laiku.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Sazinieties ar sistēmas administratoru, ja šis ziņojums tiek rādīts.. vai parādījās negaidīti",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nevarēja nosūtīt paroles maiņas e-pastu, jo lietotājam nav norādīts e-pasts. Lūdzu sazinies ar savu administratoru.",
    "Couldn't send reset email. Please make sure your username is correct." : "Nevarēja nosūtīt paroles maiņas e-pastu. Pārliecinies, ka tavs lietotājvārds ir pareizs.",
    "Dismiss" : "Atmest",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Saite paroles atiestatīšanai nosūtīta uz jūsu e-pastu. Ja tuvākajā laikā to nesaņemat, pārbaudiet pastkastes mēstuļu sadaļu. <br> Ja arī tur to neatrodat, sazinieties ar savu administratoru.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Jūsu datnes ir šifrētas. Atiestatot paroli, jums zudīs iespēja tos atšifrēt. <br />Ja neessat pārliecināts, ko darīt, sazinieties ar savu administratoru. <br />Vai tiešām vēlaties turpināt?",
    "Sending email …" : "Sūta e-pastu ...",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} zem versijas {version} ir instalēts, stabilitātes un ātruma nolūkos ir ieteicams atjaunināt {name} versiju.",
    "Shared" : "Koplietots",
    "Shared with" : "Koplietots ar",
    "Shared by" : "Koplietoja",
    "Choose a password for the public link" : "Izvēlies paroli publiskai saitei",
    "Choose a password for the public link or press the \"Enter\" key" : "Izvēlies paroli publiskai saitei vai nospiediet \"Enter\" taustiņu",
    "Copied!" : "Nokopēts!",
    "Copy link" : "Kopēt saiti",
    "Not supported!" : "Nav atbalstīts!",
    "Press ⌘-C to copy." : "Spiet ⌘-C lai kopētu.",
    "Press Ctrl-C to copy." : "Spiet Ctrl-C lai kopētu.",
    "Resharing is not allowed" : "Atkārtota koplietošana nav atļauta",
    "Link" : "Saite",
    "Password protect" : "Aizsargāt ar paroli",
    "Allow editing" : "Atļaut rediģēt",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "Allow upload and editing" : "Atļaut augšupielādi un rediģēšanu",
    "Read only" : "Tikai lasāms",
    "File drop (upload only)" : "Datņu mešana (tikai augšupielādei)",
    "Set expiration date" : "Iestatiet termiņa datumu",
    "Expiration" : "Termiņš",
    "Expiration date" : "Termiņa datums",
    "Unshare" : "Pārtraukt koplietošanu",
    "Share to {name}" : "Dalīties ar {name}",
    "Share link" : "Koplietot saiti",
    "Password protect by Talk" : "Aizsargāts ar paroli no Talk",
    "Could not unshare" : "Nevarēja pārtraukt koplietošanu",
    "Shared with you and the group {group} by {owner}" : "{owner} koplietoja ar jums un grupu {group}",
    "Shared with you and {circle} by {owner}" : " {owner} koplietoja ar tevi un {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "Dalīts ar tevi un sarunu {conversation} no {owner}",
    "Shared with you by {owner}" : "{owner} koplietoja ar jums",
    "group" : "grupa",
    "remote" : "attālināti",
    "email" : "e-pasts",
    "conversation" : "saruna",
    "shared by {sharer}" : "Koplietoja {sharer}",
    "Can reshare" : "Var atkārtoti kopīgot",
    "Can edit" : "Var rediģēt",
    "Can create" : "Var izveidot",
    "Can change" : "Var mainīt",
    "Can delete" : "Var dzēst",
    "Access control" : "Piekļuves vadība",
    "Error while sharing" : "Koplietojot notika kļūda",
    "Share details could not be loaded for this item." : "Šim nevarēja ielādēt koplietošanas detaļas.",
    "No users or groups found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs vai grupa",
    "No users found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs",
    "An error occurred. Please try again" : "Notika kļūda. Mēģini vēlreiz.",
    "Home" : "Sākums",
    "Work" : "Darbs",
    "Other" : "Cits",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Koplietot",
    "Name or email address..." : "Vārds vai e-pasta adrese...",
    "Name or federated cloud ID..." : "Vārds vai federated cloud ID",
    "Name, federated cloud ID or email address..." : "Vārds, federated cloud ID vai e-pasta adrese...",
    "Name..." : "Vārds...",
    "Error removing share" : "Kļūda, noņemot koplietošanu",
    "SQLite will be used as database." : "SQLite tiks izmantota kā datu bāze.",
    "For larger installations we recommend to choose a different database backend." : "Priekš lielākām instalācijām mēs iesakām izvēlēties citu datubāzes serveri.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Sevišķi, ja izmantojat darbvirsmas klientu datņu sinhronizācijai, SQLite izmantošana nav ieteicama.",
    "Wrong password." : "Nepareiza parole.",
    "New Password" : "Jauna parole",
    "Cancel log in" : "Atcelt pieteikšanos"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
